# Tj text - набор утилит для работы с текстом

Установить пакет в локальное окружение со всеми dev и test зависимостями можно командой

```shell
flit install
```

### Публикация пакета в pypi

Пакет публикуется в публичный pypi репозиторий 
[pypi-tj](https://pypi.org/project/tj-text/) на этапе ci по тэгу в мастер.

Для публикации используется общий аккаунт `tinkoffjournal`. 
Спросить про доступы можно у @v.troflyanin.

> **Attention**
> 
> Планируем переезжать на публикацию во внутренний registry
> Но пока все еще заливаем на pypi
> Для публикации новой версии выполнить команду `FLIT_USERNAME=__token__ flit publish`


### Версионирование

Поднятие версии делаем отдельным коммитом с описанием изменений.